\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{CGLarticle}[2008/11/27 Version 0.0 Takis Perakis]
\RequirePackage{graphicx}
\RequirePackage{multicol}
\RequirePackage{url}


\newcommand{\CGLaff}{%
    Computer Graphics Laboratory\\
    Department of Informatics and Telecommunications\\
    University of Athens, GREECE
}
\newcommand{\defaultaffiliation}{\CGLaff}

\newcommand{\CGL@cvr}{
    {\small
        {\bfseries Computer Graphics Laboratory}\\
        Department of Informatics and Telecommunications\\
        University of Athens\\
        15784 Ilisia\\
        GREECE\\
        \url{http://graphics.di.uoa.gr}
    }
}


\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
% style for vectors
\DeclareOption{vecphys}{\def\vec@style{phys}}
\DeclareOption{vecarrow}{\def\vec@style{arrow}}

\ProcessOptions
\LoadClass[11pt,a4paper,twoside]{article}

%
%   Defining the page size
%
\voffset        -1in
\hoffset        -1in
\topmargin       0mm
\headheight     30mm
\headsep        10mm
\footskip       10mm
\textheight    220mm
\setlength{\textwidth}{140mm}
\oddsidemargin   40mm
\evensidemargin  30mm

\renewcommand{\textfraction}{0.2}
\renewcommand{\bottomfraction}{0.8}
\renewcommand{\topfraction}{0.8}
\renewcommand{\floatpagefraction}{0.8}

 \newif\ifthanks
 \newbox\@kapbox
 \newcount\@kapcount

 \newtoks\t@a
 \newtoks\t@b
 \long\def\append@item#1\to#2{\t@a={\@k@p{#1}}\t@b=\expandafter{#2}%
   \xdef#2{\the\t@b\the\t@a}}
 \def\get@left#1\to#2{\expandafter\g@l#1\g@l#1#2}
 \long\def\g@l\@k@p#1#2\g@l#3#4{\def#4{#1}\def#3{#2}}


 \def\@authors{}
 \def\@allauthors{}
 \def\@institutes{}
 \def\authors@institute{}

 \def\author@#1{\append@item#1\to\@authors
   \append@item#1\to\@allauthors}
 \def\institute@#1{\append@item#1\to\@institutes
   \expandafter\append@item\expandafter{\@authors}\to\authors@institute
   \gdef\@authors{}}

 \let\author=\author@
 \let\oneauthor=\author@
 \let\institute=\institute@

 \def\@formatname#1#2{\@kapcount\c@footnote\begingroup
   \def\thanks##1{\global\thankstrue}\setbox\@kapbox\vbox{#1}\endgroup
   \c@footnote\@kapcount
   \begingroup
   \ifthanks
   \def\fn##1\thanks##2{{##1}\hbox
     to 0pt{#2\hss}\thanks{##2}}\expandafter\fn#1
   \else
   \def\fn##1{{##1}#2}\expandafter\fn\expandafter{#1}\fi
   \endgroup\global\thanksfalse}


 \def\@formatauthors{{\small\begingroup
     \newcount\cnt@authors
     \cnt@authors=0\def\@k@p##1{\advance\cnt@authors by 1}\@curauths
     \def\@k@p##1{\advance\cnt@authors by -1
       \ifnum\cnt@authors>1 \hbox{\@formatname{##1}{,}\penalty-1000}\space\fi
       \ifnum\cnt@authors=1 \hbox{\@formatname{##1}{} and\penalty-1000}\space\fi
       \ifnum\cnt@authors<1 \hbox{\@formatname{##1}{}}\par\fi}\@curauths
     \endgroup}}


 \def\@formatinstitute{{\@curinst\par}}

 \newif\if@runningtitleset
 \newif\if@runningauthorset

 \def\runningauthor#1{\if@runningauthorset\else
   \xdef\@runningauthor{{#1}}\fi
   \global\@runningauthorsettrue}
 \gdef\@runningauthor{}


 \def\@formatauthorsandinstitutes{\begingroup
   \newcount\cnt@institutes
   \newcount\cnt@authors
   \newbox\@authbox
   \cnt@authors=0\def\@k@p##1{\advance\cnt@authors by 1}\@allauthors
   \xdef\@authnames{}%
   \begingroup
     \def\thanks##1{}%
     \def\@k@p##1{\advance\cnt@authors by -1
       \ifnum\cnt@authors=0 \xdef\@authnames{\@authnames ##1}\fi
       \ifnum\cnt@authors=1 \xdef\@authnames{##1\ and }\fi
       \ifnum\cnt@authors>1 \xdef\@authnames{##1\ et al.}\cnt@authors=0\fi}%
     \global\setbox\@authbox=\hbox{\@allauthors}%
     \expandafter\runningauthor\expandafter{\@authnames}
   \endgroup
   \cnt@institutes=0
   \def\@k@p##1{\advance\cnt@institutes by 1}\@institutes
   \loop\ifnum\cnt@institutes>0
     \get@left\authors@institute\to\@curauths
     {\normalsize\sffamily\bfseries\noindent\@formatauthors}
     \get@left\@institutes\to\@curinst
     {\normalsize\sffamily\noindent\@formatinstitute}
     \ifnum\cnt@institutes=2
       \vskip 0.4\baselineskip
       %%      and   <<<==== this is ugly
     \fi
     \ifnum\cnt@institutes>1
       \vskip 0.4\baselineskip
     \fi
     \advance\cnt@institutes by -1
   \repeat\endgroup}

\newif\if@subtitle
\@subtitlefalse
\def\subtitle#1{\@subtitletrue\gdef\@subtitle{#1}}

\newif\if@affiliation
\@affiliationfalse
\def\affiliation#1{\@affiliationtrue\gdef\@affiliation{#1}}

\newif\if@version
\@versionfalse
\def\version#1#2{\@versiontrue\gdef\@versionhead{#1}\gdef\@versiontail{#2}}


\newif\if@abstract
\@abstractfalse
\renewcommand{\abstract}[1]{\@abstracttrue\gdef\@abstract{#1}}

\newif\if@keywords
\@keywordsfalse
\newcommand{\keywords}[1]{\@keywordstrue\gdef\@keywords{#1}}



\newif\if@acknowledge
\@acknowledgefalse
\newcommand{\acknowledge}[1]{\@acknowledgetrue\gdef\@acknowledge{#1}}

\newif\if@CGLreport
\@CGLreportfalse
\newcommand{\CGLreport}[1]{\@CGLreporttrue\gdef\@CGLreport{#1}}

\newif\if@CGLreportdate
\@CGLreportdatefalse
\newcommand{\CGLreportdate}[1]{\@CGLreportdatetrue\gdef\@CGLreportdate{#1}}


\AtEndDocument{\CGL@backcoverpage{\@CGLreport}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Headers and Footers
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\ps@CGLhead{%
   \let\@oddfoot\@empty
   \let\@evenfoot\@empty
   \def\@evenhead{%
       \parbox{\textwidth}{\sffamily\thepage\hfill\leftmark\\
       \rule[1.5ex]{\textwidth}{.1pt}}}
   \def\@oddhead{%
       \parbox{\textwidth}{\sffamily\rightmark\hfill\thepage\\
       \rule[1.5ex]{\textwidth}{.1pt}}}
   \let\@mkboth\markboth
   \def\sectionmark##1{%
       \markboth{\@runningauthor}{%
       \ifnum \c@secnumdepth >\m@ne
           Section \thesection\hskip 1em\relax
       \fi
       ##1}}}

\pagestyle{CGLhead}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Sans Serif font for sections
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\@sectionfont{\bf\sffamily}
\renewcommand{\section}{\@startsection {section}{1}{\z@}%
    {-3.5ex \@plus -1ex \@minus -.2ex}%
    {2.3ex \@plus.2ex}%
    {\reset@font\Large\@sectionfont}}
\renewcommand{\subsection}{\@startsection{subsection}{2}{\z@}%
    {-3.25ex\@plus -1ex \@minus -.2ex}%
    {1.5ex \@plus .2ex}%
    {\reset@font\large\@sectionfont}}
\renewcommand{\subsubsection}{\@startsection{subsubsection}{3}{\z@}%
    {-3.25ex\@plus -1ex \@minus -.2ex}%
    {1.5ex \@plus .2ex}%
    {\reset@font\normalsize\@sectionfont}}
\renewcommand{\paragraph}{\@startsection{paragraph}{4}{\z@}%
    {3.25ex \@plus1ex \@minus.2ex}%
    {-1em}%
    {\reset@font\normalsize\bfseries}}
\renewcommand{\subparagraph}{\@startsection{subparagraph}{5}{\parindent}%
    {3.25ex \@plus1ex \@minus .2ex}%
    {-1em}%
    {\reset@font\normalsize\bfseries}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% redefines the \vec accent to a bold character - if desired
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\fig@type{arrow}% temporarily abused
\ifx\vec@style\fig@type\else
\@ifundefined{vec@style}{%
 \def\vec#1{\ensuremath{\mathchoice
                     {\mbox{\boldmath$\displaystyle\mathbf{#1}$}}
                     {\mbox{\boldmath$\textstyle\mathbf{#1}$}}
                     {\mbox{\boldmath$\scriptstyle\mathbf{#1}$}}
                     {\mbox{\boldmath$\scriptscriptstyle\mathbf{#1}$}}}}%
}
{\def\vec#1{\ensuremath{\mathchoice
                     {\mbox{\boldmath$\displaystyle#1$}}
                     {\mbox{\boldmath$\textstyle#1$}}
                     {\mbox{\boldmath$\scriptstyle#1$}}
                     {\mbox{\boldmath$\scriptscriptstyle#1$}}}}%
}
\fi
% tensor
\def\tens#1{\relax\ifmmode\mathsf{#1}\else\textsf{#1}\fi}

% end of proof symbol


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Front cover page
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewcommand{\maketitle}{%
    %
    %   Outside front cover page
    %
    \thispagestyle{empty}
    \enlargethispage{20cm}  % just to make sure LaTeX doesn't
                            % generate a new page
    \vspace*{-3.5cm}\hspace*{-2cm}
    \noindent
    \begin{minipage}[t][27cm][t]{15cm}
 
            \if@CGLreport
                \vspace*{1.5ex}\noindent
                \textsf{CGL Technical Report, No.\ \@CGLreport}%
                \if@CGLreportdate%
                    , \@CGLreportdate
                \else
                    , {\large NO DATE GIVEN}
                \fi
                \\[3cm]
            \else
                \mbox{}\\[5cm]
            \fi
            \noindent\@maketitle
            \if@abstract\vspace{3cm}
		    \begin{tabular}{lp{6cm}}
                    {\bf\normalsize Abstract\hspace{2mm}} &
                    \parbox[t]{10cm}{\small\@abstract} \\
                    \vspace*{0.5ex}\mbox{}&\\
			  {\bf\normalsize Keywords\hspace{2mm}} &
                    \parbox[t]{10cm}{\small\@keywords}

                \end{tabular}
		    \fi
            
            \if@version
                \vfill
                \begin{tabular}{lp{6cm}}
                    {\bf\normalsize\@versionhead\hspace{2mm}} &
                    \parbox[t]{10cm}{\small\@versiontail}
                \end{tabular}
            \fi
    \end{minipage}
    %
    %   Inside front cover page
    %
    \newpage
    \let\CGL@tempevenhead\@evenhead
    \let\@evenhead\@empty	
    \enlargethispage{2cm}
    \vspace*{\fill}
   
    \noindent\begin{tabular}{@{}lr@{}} \hline
                \begin{minipage}[t]{.75\textwidth}
                    \vspace*{2mm}
                    \CGL@cvr
                \end{minipage}
                \vspace*{0.5ex}\mbox{}&\\
              \end{tabular}

   \newpage
   \let\@evenhead\CGL@tempevenhead
   \setcounter{page}\z@
   \let\CGL@tempevenhead\@evenhead
   \def\@evenhead{%
        \parbox{\textwidth}{\sffamily\@title\hfill\\
        \rule[1.5ex]{\textwidth}{0.1pt}}}

   \tableofcontents
   \vspace*{\fill}	
   \ifodd \count0 \else\newpage \vspace*{\fill} 
   \fi
   \setcounter{page}\z@
   \newpage
   \let\@evenhead\CGL@tempevenhead
}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Title making
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\@titlefont{\sffamily}
\def\@maketitle{%
    {\LARGE\@titlefont\noindent\@title\\[.5ex]}
    \if@subtitle{\Large\@titlefont\noindent\@subtitle}\fi
    \hspace{0pt}\\[1.5cm]
    \@formatauthorsandinstitutes
}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Figures
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  {\sffamily\bfseries\small #1:}\hspace{.5em}#2
  \vskip\belowcaptionskip}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Back cover page
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% The back cover page contains acknowledgements.

\newcommand{\CGL@backcoverpage}[1]{
    \cleardoublepage
    \let\CGL@oddtemphead\@oddhead
    \def\@oddhead{}
    \if@acknowledge\noindent\parbox[t]{\textwidth}{
        \section*{Acknowledgements}
        \@acknowledge
    } \fi
    \newpage
    \enlargethispage{2cm}
    \let\@oddhead\CGL@oddtemphead
    \thispagestyle{empty}
    \vspace*{\fill}
}


\newenvironment{CGLbibliography}[1]
     {\small%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}



\endinput

